Package: MicroMoB
Type: Package
Title: Discrete Time Simulation of Mosquito-Borne Pathogen Transmission
Version: 0.1.2
Authors@R: c(
      person("Sean L.", "Wu", email = "slwood89@gmail.com", role = c("aut","cre"), comment = c(ORCID = "0000-0002-5781-9493")),
      person("David L.", "Smith", email = "smitdave@uw.edu", role = "aut", comment = c(ORCID = "0000-0003-4367-3849")),
      person("Sophie", "Libkind", role = "ctb")
    )
Description: Provides a framework based on S3 dispatch for constructing models
  of mosquito-borne pathogen transmission which are constructed from submodels of various
  components (i.e. immature and adult mosquitoes, human populations). A consistent mathematical
  expression for the distribution of bites on hosts means that different models
  (stochastic, deterministic, etc.) can be coherently incorporated and updated
  over a discrete time step.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.2.1.9000
Imports: abind, jsonlite
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), ggplot2, data.table,
        callr, httr, readr, withr, plumber
VignetteBuilder: knitr
URL: https://dd-harp.github.io/MicroMoB/,
        https://github.com/dd-harp/MicroMoB
BugReports: https://github.com/dd-harp/MicroMoB/issues
NeedsCompilation: yes
Packaged: 2023-01-17 01:29:10 UTC; slwu89
Author: Sean L. Wu [aut, cre] (<https://orcid.org/0000-0002-5781-9493>),
  David L. Smith [aut] (<https://orcid.org/0000-0003-4367-3849>),
  Sophie Libkind [ctb]
Maintainer: Sean L. Wu <slwood89@gmail.com>
Repository: CRAN
Date/Publication: 2023-01-17 03:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 22:09:55 UTC; unix
Archs: MicroMoB.so.dSYM
