# Generated by roxygen2: do not edit by hand

S3method(compute_H,MOI)
S3method(compute_H,SIP)
S3method(compute_H,SIR)
S3method(compute_H,SIS)
S3method(compute_O,trace)
S3method(compute_Psi,MOI)
S3method(compute_Psi,SIP)
S3method(compute_Psi,SIR)
S3method(compute_Psi,SIS)
S3method(compute_Wd,trace)
S3method(compute_Z,BQ)
S3method(compute_Z,RM)
S3method(compute_Z,trace)
S3method(compute_emergents,BH)
S3method(compute_emergents,trace)
S3method(compute_emergents,trace_deterministic)
S3method(compute_emergents,trace_stochastic)
S3method(compute_f,BQ)
S3method(compute_f,RM)
S3method(compute_f,trace)
S3method(compute_oviposit,BQ)
S3method(compute_oviposit,BQ_deterministic)
S3method(compute_oviposit,BQ_stochastic)
S3method(compute_oviposit,RM)
S3method(compute_oviposit,RM_deterministic)
S3method(compute_oviposit,RM_stochastic)
S3method(compute_oviposit,trace)
S3method(compute_q,BQ)
S3method(compute_q,RM)
S3method(compute_q,trace)
S3method(compute_wf,MOI)
S3method(compute_wf,SIP)
S3method(compute_wf,SIR)
S3method(compute_wf,SIS)
S3method(compute_x,MOI)
S3method(compute_x,SIP)
S3method(compute_x,SIR)
S3method(compute_x,SIS)
S3method(compute_xd,trace)
S3method(observe_pfpr,SIP)
S3method(observe_pfpr,SIS)
S3method(output_aqua,BH)
S3method(output_aqua,trace)
S3method(output_mosquitoes,RM)
S3method(output_mosquitoes,trace)
S3method(step_aqua,BH)
S3method(step_aqua,BH_deterministic)
S3method(step_aqua,BH_stochastic)
S3method(step_aqua,trace)
S3method(step_humans,MOI)
S3method(step_humans,MOI_deterministic)
S3method(step_humans,MOI_stochastic)
S3method(step_humans,SIP)
S3method(step_humans,SIP_deterministic)
S3method(step_humans,SIP_stochastic)
S3method(step_humans,SIR)
S3method(step_humans,SIR_deterministic)
S3method(step_humans,SIR_stochastic)
S3method(step_humans,SIS)
S3method(step_humans,SIS_deterministic)
S3method(step_humans,SIS_stochastic)
S3method(step_mosquitoes,BQ)
S3method(step_mosquitoes,BQ_deterministic)
S3method(step_mosquitoes,BQ_stochastic)
S3method(step_mosquitoes,RM)
S3method(step_mosquitoes,RM_deterministic)
S3method(step_mosquitoes,RM_stochastic)
S3method(step_mosquitoes,trace)
export(api_config_global)
export(approx_equal)
export(compute_H)
export(compute_O)
export(compute_Psi)
export(compute_Wd)
export(compute_Z)
export(compute_bloodmeal)
export(compute_bloodmeal_simple)
export(compute_emergents)
export(compute_f)
export(compute_oviposit)
export(compute_q)
export(compute_wf)
export(compute_x)
export(compute_xd)
export(distribute)
export(divmod)
export(draw_multinom)
export(get_K_aqua_BH)
export(get_config_alternative_trace)
export(get_config_aqua_BH)
export(get_config_aqua_trace)
export(get_config_humans_MOI)
export(get_config_humans_SIR)
export(get_config_humans_SIS)
export(get_config_mosquito_RM)
export(get_config_mosquito_trace)
export(get_config_visitor_trace)
export(get_eip_mosquito_RM)
export(get_f_mosquito_RM)
export(get_kappa_mosquito_RM)
export(get_lambda_aqua_trace)
export(get_molt_aqua_BH)
export(get_nu_mosquito_RM)
export(get_p_mosquito_RM)
export(get_psi_mosquito_RM)
export(get_q_mosquito_RM)
export(get_surv_aqua_BH)
export(get_tmax)
export(get_tnow)
export(is_binary)
export(make_MicroMoB)
export(observe_pfpr)
export(output_aqua)
export(output_mosquitoes)
export(sample_stochastic_matrix)
export(sample_stochastic_vector)
export(set_K_aqua_BH)
export(set_eip_mosquito_RM)
export(set_f_mosquito_RM)
export(set_kappa_mosquito_RM)
export(set_lambda_aqua_trace)
export(set_molt_aqua_BH)
export(set_nu_mosquito_RM)
export(set_p_mosquito_RM)
export(set_psi_mosquito_RM)
export(set_q_mosquito_RM)
export(set_surv_aqua_BH)
export(setup_alternative_trace)
export(setup_aqua_BH)
export(setup_aqua_trace)
export(setup_humans_MOI)
export(setup_humans_SIP)
export(setup_humans_SIR)
export(setup_humans_SIS)
export(setup_mosquito_BQ)
export(setup_mosquito_RM)
export(setup_mosquito_trace)
export(setup_visitor_trace)
export(step_aqua)
export(step_humans)
export(step_mosquitoes)
export(strata_to_residency_counts)
export(strata_to_residency_proportion)
export(time_patch_varying_parameter)
export(time_varying_parameter)
importFrom(abind,abind)
importFrom(jsonlite,read_json)
importFrom(jsonlite,unbox)
importFrom(stats,pexp)
importFrom(stats,rbinom)
importFrom(stats,rhyper)
importFrom(stats,rmultinom)
importFrom(stats,rpois)
importFrom(utils,tail)
useDynLib(MicroMoB, .registration = TRUE)
